import os
import sys

from fastapi.testclient import TestClient

here = os.path.abspath(os.path.dirname(__file__))
root = os.path.dirname(here)
examples = os.path.join(root, "examples")

sys.path.insert(0, examples)
sys.path.insert(0, root)

from flux_restful_client import get_basic_auth  # noqa

# Define authentication in environment for server
flux_user = "fluxuser"
flux_token = "12345"
os.environ["FLUX_USER"] = flux_user
os.environ["FLUX_TOKEN"] = flux_token
os.environ["FLUX_REQUIRE_AUTH"] = "true"


from app.main import app  # noqa

client = TestClient(app)


def get_headers():
    auth_header = get_basic_auth(flux_user, flux_token)
    if isinstance(auth_header, bytes):
        auth_header = auth_header.decode("utf-8")
    return {"Authorization": "Basic %s" % auth_header}


def test_submit_list_job():

    # No jobs are submit!
    response = client.get("/jobs")
    assert response.status_code == 401
    assert "www-authenticate" in response.headers

    headers = get_headers()
    response = client.get("/jobs", headers=headers)
    assert response.status_code == 200

    # Now submit a job, ensure we get one job back
    response = client.post("/jobs/submit", json={"command": "sleep 5"}, headers=headers)
    assert response.status_code == 200
    result = response.json()
    assert "id" in result
    jobid = result["id"]

    response = client.get("/jobs", headers=headers)
    assert response.status_code == 200
    result = response.json()
    assert "jobs" in result
    result = result["jobs"]
    assert len(result) == 1
    assert result[0]["id"] == jobid


def test_cancel_job():

    headers = get_headers()

    # Now submit a job, ensure we get one job back
    response = client.post(
        "/jobs/submit", json={"command": "sleep 10"}, headers=headers
    )
    assert response.status_code == 200
    result = response.json()
    jobid = result["id"]
    response = client.post(f"/jobs/{jobid}/cancel", headers=headers)
    assert response.status_code == 200
    # TODO we don't have way to actually verify this!



import errno
import io
import json
import os
import re
import shutil
import stat
import tempfile

from flux_restful_client.logger import logger

try:
    from ruamel_yaml import YAML
except ImportError:
    from ruamel.yaml import YAML


def mkdirp(dirnames):
    """
    Create one or more directories
    """
    for dirname in dirnames:
        mkdir_p(dirname)


def mkdir_p(path):
    """
    Make a directory path if it does not exist, akin to mkdir -p
    """
    try:
        os.makedirs(path)
    except OSError as e:
        if e.errno == errno.EEXIST and os.path.isdir(path):
            pass
        else:
            logger.exit("Error creating path %s, exiting." % path)


def get_tmpfile(tmpdir=None, prefix=""):
    """
    Get a temporary file with an optional prefix.
    """

    # First priority for the base goes to the user requested.
    tmpdir = get_tmpdir(tmpdir)

    # If tmpdir is set, add to prefix
    if tmpdir:
        prefix = os.path.join(tmpdir, os.path.basename(prefix))

    fd, tmp_file = tempfile.mkstemp(prefix=prefix)
    os.close(fd)

    return tmp_file


def get_tmpdir(tmpdir=None, prefix="", create=True):
    """
    Get a temporary directory for an operation.
    """
    tmpdir = tmpdir or tempfile.gettempdir()
    prefix = prefix or "action-updater-tmp"
    prefix = "%s.%s" % (prefix, next(tempfile._get_candidate_names()))
    tmpdir = os.path.join(tmpdir, prefix)

    if not os.path.exists(tmpdir) and create is True:
        os.mkdir(tmpdir)

    return tmpdir


def recursive_find(base, pattern=None):
    """
    Find filenames that match a particular pattern, and yield them.
    """
    # We can identify modules by finding module.lua
    for root, _, files in os.walk(base):
        for file in files:
            fullpath = os.path.abspath(os.path.join(root, file))
            if pattern and not re.search(pattern, fullpath):
                continue
            yield fullpath


def copyfile(source, destination, force=True):
    """
    Copy a file from a source to its destination.
    """
    # Case 1: It's already there, we aren't replacing it :)
    if source == destination and force is False:
        return destination

    # Case 2: It's already there, we ARE replacing it :)
    if os.path.exists(destination) and force is True:
        os.remove(destination)

    shutil.copyfile(source, destination)
    return destination


def write_file(filename, content, mode="w", exec=False):
    """
    Write content to a filename
    """
    with open(filename, mode) as filey:
        filey.writelines(content)
    if exec:
        st = os.stat(filename)

        # Execute / search permissions for the user and others
        os.chmod(filename, st.st_mode | stat.S_IEXEC | stat.S_IXGRP | stat.S_IXOTH)
    return filename


def write_json(json_obj, filename, mode="w"):
    """
    Write json to a filename
    """
    with open(filename, mode) as filey:
        filey.writelines(print_json(json_obj))
    return filename


def print_json(json_obj):
    """
    Print json pretty
    """
    return json.dumps(json_obj, indent=4, separators=(",", ": "))


def write_yaml(obj, filename, line_length=None):
    """
    Save yaml to file, also preserving comments.
    """
    yaml = YAML()
    yaml.preserve_quotes = True

    with open(filename, "w") as fd:
        yaml.dump(obj, fd)


def get_yaml_string(obj):
    """
    Get yaml output as string
    """
    # Prepare to dump formatted yaml
    yaml = YAML()
    yaml.preserve_quotes = True
    out = io.StringIO()
    yaml.dump(obj, out)
    return out.getvalue()


def read_yaml(filename):
    """
    Load a yaml from file, roundtrip to preserve comments
    """
    yaml = YAML()
    with open(filename, "r") as fd:
        content = yaml.load(fd.read())
    return content


def read_file(filename, mode="r"):
    """
    Read a file.
    """
    with open(filename, mode) as filey:
        content = filey.read()
    return content


def read_json(filename, mode="r"):
    """
    Read a json file to a dictionary.
    """
    return json.loads(read_file(filename))



import os
from copy import deepcopy

import flux_restful_client.main.schemas as schemas
import flux_restful_client.utils as utils
import jsonschema
import requests
from flux_restful_client.logger import logger

from .settings import Settings


class FluxRestfulClient:
    """
    Create a FluxRestful Client to interact with the Flux RESTFul API server.
    """

    def __init__(
        self,
        host=None,
        user=None,
        token=None,
        quiet=False,
        settings_file=None,
        **kwargs,
    ):

        # If we don't have default settings, load
        if not hasattr(self, "settings"):
            self.settings = Settings(settings_file)

        self.host = host or self.settings.host
        self.user = user or os.environ.get("FLUX_USER") or self.settings.flux_user
        self.token = token or os.environ.get("FLUX_TOKEN") or self.settings.flux_token
        self.headers = {}
        if self.user and self.token:
            self.set_basic_auth(self.user, self.token)
        self.session = requests.Session()

    def set_header(self, name, value):
        self.headers.update({name: value})

    def set_basic_auth(self, username, password):
        """
        A wrapper to adding basic authentication to the Request
        """
        auth_header = utils.get_basic_auth(username, password)
        if isinstance(auth_header, bytes):
            auth_header = auth_header.decode("utf-8")
        self.set_header("Authorization", "Basic %s" % auth_header)

    def reset(self):
        """
        Reset and prepare for a new request.
        """
        if "Authorization" in self.headers:
            self.headers = {"Authorization": self.headers["Authorization"]}
        else:
            self.headers = {}

    def do_request(self, endpoint, method="GET", data=None, headers=None):
        """
        Do a request. This is a wrapper around requests.
        """
        # Always reset headers for new request.
        self.reset()

        headers = headers or self.headers
        url = "%s/%s" % (self.host, endpoint)

        # Make the request and return to calling function, unless requires auth
        response = self.session.request(method, url, json=data, headers=headers)

        # A 401 response is a request for authentication
        if response.status_code != 401:
            return response

        # Otherwise, authenticate the request and retry
        if self.authenticate_request(response):
            return self.session.request(method, url, json=data, headers=self.headers)
        return response

    def authenticate_request(self, originalResponse):
        """
        Authenticate Request
        Given a response, look for a Www-Authenticate header to parse. We
        return True/False to indicate if the request should be retried.
        """
        authHeaderRaw = originalResponse.headers.get("Www-Authenticate")
        if not authHeaderRaw:

            return False

        # If we have a username and password, set basic auth automatically
        if self.token and self.username:
            self.set_basic_auth(self.username, self.token)

        headers = deepcopy(self.headers)
        if "Authorization" not in headers:
            logger.error(
                "This endpoint requires a token. Please set "
                "client.set_basic_auth(username, password) first "
                "or export them to the environment."
            )
            return False

        # Prepare request to retry
        h = utils.parse_auth_header(authHeaderRaw)
        headers.update(
            {
                "service": h.Service,
                "Accept": "application/json",
                "User-Agent": "flux-restful-client",
            }
        )

        # Currently we don't set a scope (it defaults to build)
        authResponse = self.session.request("GET", h.Realm, headers=headers)
        if authResponse.status_code != 200:
            return False

        # Request the token
        info = authResponse.json()
        token = info.get("token")
        if not token:
            token = info.get("access_token")

        # Set the token to the original request and retry
        self.headers.update({"Authorization": "Bearer %s" % token})
        return True

    def list_nodes(self):
        """
        List nodes available.
        """
        return self.do_request("nodes", "GET").json()

    def cancel(self, jobid):
        """
        Request for a job to be cancelled based on identifier.
        """
        return self.do_request(f"jobs/{jobid}/cancel", "POST").json()

    def stop_service(self):
        """
        Stop the server running.
        """
        return self.do_request("service/stop", "POST").json()

    def jobs(self, jobid=None):
        """
        Get a listing of jobs that the Flux RESTful API knows about!
        """
        endpoint = "jobs"
        if jobid:
            endpoint += "/" + str(jobid)
        result = self.do_request(endpoint, "GET")
        if result.status_code == 404:
            print("There is no job for that identifier.")
            return
        return result.json()

    def submit(self, command, **kwargs):
        """
        Submit a job to the Flux RESTful API

        Optional kwargs that are accepted include:
        workdir (str): a working directory for the job
        num_tasks (int): Number of tasks (defaults to 1)
        cores_per_task (int): Number of cores per task (default to 1)
        gpus_per_task (int): Number of gpus per task (defaults to None)
        num_nodes (int): Number of nodes (defaults to None)
        exclusive (bool): is the job exclusive? (defaults to False)
        """
        # Allow the user to provide a list (and stringify everything)
        if isinstance(command, list):
            command = " ".join([str(x) for x in command])
        data = {"command": command}
        for optional in [
            "num_tasks",
            "cores_per_task",
            "gpus_per_task",
            "num_nodes",
            "exclusive",
            "workdir",
            "envars",
        ]:

            # Assume if it's provided, period, the user wants to set it!
            if optional in kwargs:
                data[optional] = kwargs[optional]

        # Validate the data first.
        jsonschema.validate(data, schema=schemas.job_submit_schema)
        result = self.do_request("jobs/submit", "POST", data=data)
        if result.status_code == 404:
            print("There is no job for that identifier.")
            return
        return result.json()

    def __repr__(self):
        return str(self)

    def __str__(self):
        return "[flux-restful-client]"



#!/usr/bin/env python

import argparse
import os
import sys

import flux_restful_client
import flux_restful_client.main.schemas as schemas
from flux_restful_client.logger import setup_logger


def add_submit_arguments(command):
    """
    Derive the command for argparse directly from the schema
    """
    # All all options (based on type) except for command, which comes in "extra"
    for name, attrs in schemas.submit_properties.items():
        if name == "command":
            continue
        typ = attrs.get("type")
        default_type = str
        action = None

        # It's either a string...
        if typ == "number" or "number" in typ:
            default_type = int
        elif typ == "boolean" or "boolean" in typ:
            default_type = bool
            # Assume default is always false for now
            action = "store_true"

        if default_type == bool:
            command.add_argument(
                f"--{name}",
                help=attrs.get("description") or f"The --{name} flag.",
                action=action,
            )
        else:
            command.add_argument(
                f"--{name}",
                help=attrs.get("description") or f"The --{name} flag.",
                type=default_type,
            )


def get_parser():
    parser = argparse.ArgumentParser(
        description="😴 Flux Restful Client Python",
        formatter_class=argparse.RawTextHelpFormatter,
    )

    # Global Variables
    parser.add_argument(
        "--debug",
        dest="debug",
        help="use verbose logging to debug.",
        default=False,
        action="store_true",
    )

    parser.add_argument(
        "--quiet",
        dest="quiet",
        help="suppress additional output.",
        default=False,
        action="store_true",
    )

    parser.add_argument(
        "--version",
        dest="version",
        help="show software version.",
        default=False,
        action="store_true",
    )

    parser.add_argument(
        "--settings-file",
        dest="settings_file",
        help="custom path to settings file.",
    )

    # On the fly updates to config params
    parser.add_argument(
        "-c",
        dest="config_params",
        help=""""customize a config value on the fly to ADD/SET/REMOVE for a command
action-updater -c set:key:value <command> <args>
action-updater -c add:listkey:value <command> <args>
action-updater -c rm:listkey:value""",
        action="append",
    )

    subparsers = parser.add_subparsers(
        help="actions",
        title="actions",
        description="actions",
        dest="command",
    )

    # print version and exit
    subparsers.add_parser("version", description="show software version")

    # Submit a job (all extra is the command)
    submit = subparsers.add_parser(
        "submit",
        description="submit a job via the flux restful client",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    add_submit_arguments(submit)

    # Local shell with client loaded
    shell = subparsers.add_parser(
        "shell",
        description="shell into a Python session with a client.",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    shell.add_argument(
        "--interpreter",
        "-i",
        dest="interpreter",
        help="python interpreter",
        choices=["ipython", "python", "bpython"],
        default="ipython",
    )

    config = subparsers.add_parser(
        "config",
        description="update configuration settings. Use set or get to see or set information.",
        formatter_class=argparse.RawTextHelpFormatter,
    )

    config.add_argument(
        "--central",
        dest="central",
        help="make edits to the central config file.",
        default=False,
        action="store_true",
    )

    config.add_argument(
        "params",
        nargs="*",
        help="""Set or get a config value, edit the config, add or remove a list variable, or create a user-specific config.
flux-restful-cli config set key value
flux-restful-cli config set key:subkey value
flux-restful-cli config get key
flux-restful-cli edit
flux-restful-cli config inituser""",
        type=str,
    )

    cancel = subparsers.add_parser(
        "cancel",
        description="cancel a job",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    info = subparsers.add_parser(
        "info",
        description="get information for a job",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    subparsers.add_parser(
        "list-nodes",
        description="list node that the Flux RESTful API knows about",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    subparsers.add_parser(
        "list-jobs",
        description="list jobs that the Flux RESTful API knows about",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    subparsers.add_parser(
        "stop-service",
        description="Kill your Flux RESTFul API server (cannot be undone)",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    for command in cancel, info:
        command.add_argument("jobid", help="The jobid to interact with.")

    return parser


def run_flux_restful_client():

    parser = get_parser()

    def help(return_code=0):
        """print help, including the software version and active client
        and exit with return code.
        """
        version = flux_restful_client.__version__

        print("\nFlux RESTFul Python Client v%s" % version)
        parser.print_help()
        sys.exit(return_code)

    # If the user didn't provide any arguments, show the full help
    if len(sys.argv) == 1:
        help()

    # If an error occurs while parsing the arguments, the interpreter will exit with value 2
    args, extra = parser.parse_known_args()

    if args.debug is True:
        os.environ["MESSAGELEVEL"] = "DEBUG"

    # Show the version and exit
    if args.command == "version" or args.version:
        print(flux_restful_client.__version__)
        sys.exit(0)

    setup_logger(
        quiet=args.quiet,
        debug=args.debug,
    )

    # retrieve subparser (with help) from parser
    helper = None
    subparsers_actions = [
        action
        for action in parser._actions
        if isinstance(action, argparse._SubParsersAction)
    ]
    for subparsers_action in subparsers_actions:
        for choice, subparser in subparsers_action.choices.items():
            if choice == args.command:
                helper = subparser
                break

    if args.command == "info":
        from .info import main
    elif args.command == "cancel":
        from .cancel import main
    elif args.command == "config":
        from .config import main
    elif args.command == "stop-service":
        from .stop import stop_service as main
    elif args.command == "list-jobs":
        from .listing import list_jobs as main
    elif args.command == "list-nodes":
        from .listing import list_nodes as main
    elif args.command == "submit":
        from .submit import main
    elif args.command == "shell":
        from .shell import main

    # Pass on to the correct parser
    return_code = 0
    try:
        main(args=args, parser=parser, extra=extra, subparser=helper)
        sys.exit(return_code)
    except UnboundLocalError:
        return_code = 1

    help(return_code)


if __name__ == "__main__":
    run_flux_restful_client()



import base64
import re


def get_basic_auth(username, password):
    auth_str = "%s:%s" % (username, password)
    return base64.b64encode(auth_str.encode("utf-8")).decode("utf-8")


def parse_auth_header(authHeaderRaw):
    """
    Parse authentication header into pieces
    """
    regex = re.compile('([a-zA-z]+)="(.+?)"')
    matches = regex.findall(authHeaderRaw)
    lookup = dict()
    for match in matches:
        lookup[match[0]] = match[1]
    return authHeader(lookup)


class authHeader:
    def __init__(self, lookup):
        """
        Given a dictionary of values, match them to class attributes
        """
        for key in lookup:
            if key in ["realm", "service", "scope"]:
                setattr(self, key.capitalize(), lookup[key])



schema_url = "http://json-schema.org/draft-07/schema"

keyvals = {
    "type": "object",
    "patternProperties": {
        "\\w[\\w-]*": {"type": "string"},
    },
}

# A job submission schema
submit_properties = {
    "workdir": {"type": ["string", "null"]},
    "command": {
        "oneOf": [
            {
                "type": "string",
            },
            {"type": "array", "items": {"type": ["string", "number"]}},
        ]
    },
    "envars": {
        "oneOf": [
            {"type": "null"},
            keyvals,
        ]
    },
    "num_tasks": {"type": "number"},
    "cores_per_task": {"type": ["number", "null"]},
    "gpus_per_task": {"type": ["number", "null"]},
    "num_nodes": {"type": ["number", "null"]},
    "exclusive": {"type": ["boolean", "null"]},
}

job_submit_schema = {
    "$schema": schema_url,
    "title": "Flux Job Submit Schema",
    "type": "object",
    "required": [
        "command",
    ],
    "properties": submit_properties,
    "additionalProperties": False,
}


# Currently all of these are required
settingsProperties = {
    "flux_token": {"type": ["string", "null"]},
    "flux_user": {"type": ["string", "null"]},
    "host": {"type": "string"},
    "config_editor": {"type": "string"},
    "workdir": {"type": ["string", "null"]},
}

settings = {
    "$schema": schema_url,
    "title": "Settings Schema",
    "type": "object",
    "required": [
        "host",
        "config_editor",
    ],
    "properties": settingsProperties,
    "additionalProperties": False,
}



import json

from flux_restful_client.main import get_client


def list_jobs(args, parser, extra, subparser):
    cli = get_client(quiet=args.quiet, settings=args.settings_file)

    # Update config settings on the fly
    cli.settings.update_params(args.config_params)
    res = cli.jobs()
    print(json.dumps(res, indent=4))


def list_nodes(args, parser, extra, subparser):
    cli = get_client(quiet=args.quiet, settings=args.settings_file)

    # Update config settings on the fly
    cli.settings.update_params(args.config_params)
    res = cli.list_nodes()
    print(json.dumps(res, indent=4))



from .auth import authHeader, get_basic_auth, parse_auth_header
from .fileio import (
    copyfile,
    get_tmpdir,
    get_tmpfile,
    get_yaml_string,
    mkdir_p,
    mkdirp,
    print_json,
    read_file,
    read_json,
    read_yaml,
    recursive_find,
    write_file,
    write_json,
    write_yaml,
)
from .terminal import confirm_action, get_installdir, run_command



import json

from flux_restful_client.logger import logger
from flux_restful_client.main import get_client


def main(args, parser, extra, subparser):
    cli = get_client(quiet=args.quiet, settings=args.settings_file)

    if not extra:
        logger.exit("Please include the command that you want to submit!")

    # Update config settings on the fly
    cli.settings.update_params(args.config_params)

    # The command is the "extra"
    kwargs = {"command": extra}
    for arg in [
        "num_tasks",
        "cores_per_task",
        "gpus_per_task",
        "num_nodes",
        "exclusive",
        "workdir",
    ]:
        if hasattr(args, arg) and getattr(args, arg, None) is not None:
            kwargs[arg] = getattr(args, arg)

    res = cli.submit(**kwargs)
    print(json.dumps(res, indent=4))



import time

from flux_restful_client.main import get_client


def test_list_nodes():
    """
    Test listing nodes
    """
    client = get_client()
    response = client.list_nodes()
    assert "nodes" in response
    assert response["nodes"]
    assert len(response["nodes"]) == 1


def test_submit_list_job():
    """
    Test a manual submission
    """
    client = get_client()

    # No jobs are submit!
    response = client.jobs()
    assert isinstance(response, dict)
    assert "jobs" in response
    assert not response["jobs"]

    # Now submit a job, ensure we get one job back
    response = client.submit("sleep 5")
    assert isinstance(response, dict)
    for key in ["Message", "id"]:
        assert key in response
    jobid = response["id"]

    # Now we should see jobs
    response = client.jobs()
    assert response["jobs"]
    assert len(response["jobs"]) == 1
    assert response["jobs"][0]["id"] == jobid


def test_cancel_job():
    client = get_client()
    response = client.submit("sleep 10")
    jobid = response["id"]
    response = client.cancel(jobid)
    assert "Message" in response
    assert "requested to cancel" in response["Message"]

    # Give time to cancel
    time.sleep(3)
    response = client.cancel(jobid)
    assert "Message" in response
    assert "cannot be cancelled" in response["Message"]



from .settings import Settings


def get_client(quiet=False, **kwargs):
    """
    Get an actions updater client.

    This will ensure we add all of the default updaters to our client.
    """
    validate = kwargs.get("validate", True)

    # Load user settings to add to client, and container technology
    settings = Settings(kwargs.get("settings_file"), validate)

    from .client import FluxRestfulClient

    FluxRestfulClient.settings = settings
    client = FluxRestfulClient(quiet=quiet, **kwargs)
    return client



import os

import flux_restful_client.utils as utils

install_dir = utils.get_installdir()
reps = {"$install_dir": install_dir, "$root_dir": os.path.dirname(install_dir)}

# The default settings file in the install root
default_settings_file = os.path.join(reps["$install_dir"], "settings.yml")

# The user settings file can be created to over-ride default
user_settings_file = os.path.join(
    os.path.expanduser("~/.flux-restful-cli"), "settings.yml"
)



import json

from flux_restful_client.main import get_client


def stop_service(args, parser, extra, subparser):
    cli = get_client(quiet=args.quiet, settings=args.settings_file)
    cli.settings.update_params(args.config_params)
    info = cli.stop_service()
    print(json.dumps(info, indent=4))



import sys

import flux_restful_client.defaults as defaults
from flux_restful_client.logger import logger
from flux_restful_client.main import get_client


def main(args, parser, extra, subparser):

    # If nothing provided, show help
    if not args.params:
        print(subparser.format_help())
        sys.exit(0)

    # The first "param" is either set of get
    command = args.params.pop(0)

    # If the user wants the central config file
    if args.central:
        args.settings_file = defaults.default_settings_file

    validate = True if not command == "edit" else False
    cli = get_client(
        quiet=args.quiet, settings_file=args.settings_file, validate=validate
    )

    # Update config settings on the fly
    cli.settings.update_params(args.config_params)

    # For each new setting, update and save!
    if command == "inituser":
        return cli.settings.inituser()
    if command == "edit":
        return cli.settings.edit()

    if command in ["set", "add", "remove"]:
        cli.settings.update_param(command, args.params)

        # Save settings
        cli.settings.save()

    # For each get request, print the param pair
    elif command == "get":
        for key in args.params:
            value = cli.settings.get(key)
            value = "is unset" if value is None else value
            logger.info("%s %s" % (key.ljust(30), value))

    else:
        logger.error("%s is not a recognized command." % command)



__version__ = "0.0.0"
AUTHOR = "Vanessa Sochat"
EMAIL = "vsoch@users.noreply.github.com"
NAME = "flux-restful-client"
PACKAGE_URL = (
    "https://github.com/flux-framework/flux-restful-api/tree/main/clients/python"
)
KEYWORDS = "flux, flux framework, client, RESTFul API"
DESCRIPTION = "Python functions and command line equivalent for interacting with Flux RESTful API."
LICENSE = "LICENSE"

################################################################################
# Global requirements

INSTALL_REQUIRES = (
    # Required to maintain comments in files
    ("ruamel.yaml", {"min_version": None}),
    ("requests", {"min_version": None}),
    ("jsonschema", {"min_version": None}),
)

TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
INSTALL_REQUIRES_ALL = INSTALL_REQUIRES + TESTS_REQUIRES
